@@ -21,7 +21,7 @@
 /*!
   \qmltype InverseMouseArea
   \instantiates InverseMouseAreaType
-  \inqmlmodule Ubuntu.Components 0.1
+  \inqmlmodule Ubuntu.Components 1.1
   \ingroup ubuntu
   \brief The InverseMouseArea captures mouse events happening outside of a given
   area.
@@ -33,7 +33,7 @@
   Popup.qml
   \qml
   import QtQuick 2.0
-  import Ubuntu.Components 0.1
+  import Ubuntu.Components 1.1
 
   Rectangle {
       anchors.centerIn: parent
@@ -53,7 +53,7 @@
 
   \qml
   import QtQuick 2.0
-  import Ubuntu.Components 0.1
+  import Ubuntu.Components 1.1
 
   Item {
       width: 640
@@ -77,7 +77,7 @@
   a component which is either a parent of the mouse area or a sibling of it.
   \qml
   import QtQuick 2.0
-  import Ubuntu.Components 0.1
+  import Ubuntu.Components 1.1
 
   Item {
       width: units.gu(40)
@@ -244,11 +244,6 @@ InverseMouseAreaType::InverseMouseAreaType(QQuickItem *parent) :
      */
     QObject::connect(this, &QQuickMouseArea::windowChanged,
                      this, &InverseMouseAreaType::resetFilterOnWindowUpdate);
-
-    if (!m_sensingArea) {
-        // get sensing area upon parent change
-        QObject::connect(this, SIGNAL(parentChanged(QQuickItem*)), this, SLOT(update()));
-    }
 }
 
 InverseMouseAreaType::~InverseMouseAreaType()
@@ -291,6 +286,7 @@ void InverseMouseAreaType::update()
         m_sensingArea = QuickUtils::instance().rootItem(this);
     }
     updateEventFilter(isEnabled() && isVisible() && m_topmostItem);
+    QQuickMouseArea::update();
 }
 /*!
   \internal
@@ -302,6 +298,14 @@ void InverseMouseAreaType::resetFilterOnWindowUpdate(QQuickWindow *win)
     updateEventFilter(m_topmostItem);
 }
 
+void InverseMouseAreaType::itemChange(ItemChange change, const ItemChangeData &data)
+{
+    if (change == ItemParentHasChanged && data.item) {
+        update();
+    }
+    QQuickMouseArea::itemChange(change, data);
+}
+
 void InverseMouseAreaType::componentComplete()
 {
     QQuickMouseArea::componentComplete();
