@@ -1,5 +1,5 @@
 /*
- * Copyright 2012 Canonical Ltd.
+ * Copyright 2012-2014 Canonical Ltd.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -16,7 +16,6 @@
  * Author: Juhapekka Piiroinen <juhapekka.piiroinen@canonical.com>
  */
 
-#include <QtQml>
 #include <QtQuick/private/qquickimagebase_p.h>
 #include <QDBusConnection>
 #include <QtGui/QGuiApplication>
@@ -32,12 +31,10 @@
 #include "ucscalingimageprovider.h"
 #include "ucqquickimageextension.h"
 #include "quickutils.h"
-#include "giconprovider.h"
 #include "shapeitem.h"
 #include "inversemouseareatype.h"
 #include "qquickclipboard.h"
 #include "qquickmimedata.h"
-#include "bottombarvisibilitycommunicator.h"
 #include "thumbnailgenerator.h"
 #include "ucubuntuanimation.h"
 #include "ucfontutils.h"
@@ -49,11 +46,20 @@
 #include "unitythemeiconprovider.h"
 #include "ucstatesaver.h"
 #include "ucurihandler.h"
+#include "ucmouse.h"
+#include "ucinversemouse.h"
+#include "sortfiltermodel.h"
+#include "ucstyleditembase.h"
+#include "ucaction.h"
+#include "ucactioncontext.h"
+#include "ucactionmanager.h"
 
 #include <sys/types.h>
 #include <unistd.h>
 #include <stdexcept>
 
+QUrl UbuntuComponentsPlugin::m_baseUrl = QUrl();
+
 /*
  * Type registration functions.
  */
@@ -85,37 +91,6 @@ static QObject *registerUriHandler(QQmlEngine *engine, QJSEngine *scriptEngine)
     return uriHandler;
 }
 
-QUrl UbuntuComponentsPlugin::baseUrl(QStringList importPathList, const char* uri)
-{
-    /* FIXME: remove when migrating to Qt 5.1 and use QQmlExtensionPlugin::baseUrl()
-       http://doc-snapshot.qt-project.org/qt5-stable/qtqml/qqmlextensionplugin.html#baseUrl
-    */
-    QString pluginRelativePath = QString::fromUtf8(uri).replace(".", "/").prepend("/").append("/");
-    QString pluginPath;
-    Q_FOREACH (QString importPath, importPathList) {
-        pluginPath = importPath.append(pluginRelativePath);
-        /* We verify that the directory ending in Ubuntu/Components contains the
-           file libUbuntuComponents.so therefore proving it's the right directory.
-
-           Ref.: https://bugs.launchpad.net/ubuntu-ui-toolkit/+bug/1197293
-        */
-        if (QFile(pluginPath + "libUbuntuComponents.so").exists()) {
-            return QUrl::fromLocalFile(pluginPath);
-        }
-    }
-
-    return QUrl();
-}
-
-void UbuntuComponentsPlugin::registerQmlSingletonType(QQmlEngine *engine, const char* uri, const char* typeName, const char* qmlFile)
-{
-    QUrl url = baseUrl(engine->importPathList(), uri).resolved(QUrl::fromLocalFile(qmlFile));
-    QObject* object = QuickUtils::instance().createQmlObject(url);
-    if (object != NULL) {
-        engine->rootContext()->setContextProperty(typeName, object);
-    }
-}
-
 void UbuntuComponentsPlugin::registerWindowContextProperty()
 {
     setWindowContextProperty(QGuiApplication::focusWindow());
@@ -141,35 +116,63 @@ void UbuntuComponentsPlugin::setWindowContextProperty(QWindow* focusWindow)
     }
 }
 
+void UbuntuComponentsPlugin::registerTypesToVersion(const char *uri, int major, int minor)
+{
+    qmlRegisterType<UCAction>(uri, major, minor, "Action");
+    qmlRegisterType<UCActionContext>(uri, major, minor, "ActionContext");
+    qmlRegisterType<UCActionManager>(uri, major, minor, "ActionManager");
+    qmlRegisterType<UCStyledItemBase>(uri, major, minor, "StyledItemBase");
+    qmlRegisterUncreatableType<UbuntuI18n>(uri, major, minor, "i18n", "Singleton object");
+    qmlRegisterExtendedType<QQuickImageBase, UCQQuickImageExtension>(uri, major, minor, "QQuickImageBase");
+    qmlRegisterUncreatableType<UCUnits>(uri, major, minor, "UCUnits", "Not instantiable");
+    qmlRegisterType<ShapeItem>(uri, major, minor, "UbuntuShape");
+    // FIXME/DEPRECATED: Shape is exported for backwards compatibity only
+    qmlRegisterType<ShapeItem>(uri, major, minor, "Shape");
+    qmlRegisterType<InverseMouseAreaType>(uri, major, minor, "InverseMouseArea");
+    qmlRegisterType<QQuickMimeData>(uri, major, minor, "MimeData");
+    qmlRegisterSingletonType<QQuickClipboard>(uri, major, minor, "Clipboard", registerClipboard);
+    qmlRegisterSingletonType<UCUbuntuAnimation>(uri, major, minor, "UbuntuAnimation", registerUCUbuntuAnimation);
+    qmlRegisterType<UCArguments>(uri, major, minor, "Arguments");
+    qmlRegisterType<UCArgument>(uri, major, minor, "Argument");
+    qmlRegisterType<QQmlPropertyMap>();
+    qmlRegisterType<UCAlarm>(uri, major, minor, "Alarm");
+    qmlRegisterType<UCAlarmModel>(uri, major, minor, "AlarmModel");
+    qmlRegisterType<UCStateSaver>(uri, major, minor, "StateSaver");
+    qmlRegisterType<UCStateSaverAttached>();
+    qmlRegisterSingletonType<UCUriHandler>(uri, major, minor, "UriHandler", registerUriHandler);
+    qmlRegisterType<UCMouse>(uri, major, minor, "Mouse");
+    qmlRegisterType<UCInverseMouse>(uri, major, minor, "InverseMouse");
+}
+
 void UbuntuComponentsPlugin::registerTypes(const char *uri)
 {
     Q_ASSERT(uri == QLatin1String("Ubuntu.Components"));
 
-    qmlRegisterUncreatableType<UbuntuI18n>(uri, 0, 1, "i18n", "Singleton object");
-    qmlRegisterExtendedType<QQuickImageBase, UCQQuickImageExtension>(uri, 0, 1, "QQuickImageBase");
-    qmlRegisterUncreatableType<UCUnits>(uri, 0, 1, "UCUnits", "Not instantiable");
-    qmlRegisterType<ShapeItem>(uri, 0, 1, "Shape");
-    qmlRegisterType<InverseMouseAreaType>(uri, 0, 1, "InverseMouseArea");
-    qmlRegisterType<QQuickMimeData>(uri, 0, 1, "MimeData");
-    qmlRegisterSingletonType<QQuickClipboard>(uri, 0, 1, "Clipboard", registerClipboard);
-    qmlRegisterSingletonType<UCUbuntuAnimation>(uri, 0, 1, "UbuntuAnimation", registerUCUbuntuAnimation);
-    qmlRegisterType<UCArguments>(uri, 0, 1, "Arguments");
-    qmlRegisterType<UCArgument>(uri, 0, 1, "Argument");
-    qmlRegisterType<QQmlPropertyMap>();
-    qmlRegisterType<UCAlarm>(uri, 0, 1, "Alarm");
-    qmlRegisterType<UCAlarmModel>(uri, 0, 1, "AlarmModel");
-    qmlRegisterType<UCStateSaver>(uri, 0, 1, "StateSaver");
-    qmlRegisterType<UCStateSaverAttached>();
-    qmlRegisterSingletonType<UCUriHandler>(uri, 0, 1, "UriHandler", registerUriHandler);
+    // register 0.1 for backward compatibility
+    registerTypesToVersion(uri, 0, 1);
+    registerTypesToVersion(uri, 1, 0);
+
+    // register custom event
+    ForwardedEvent::registerForwardedEvent();
+
+    // register parent type so that properties can get/ set it
+    qmlRegisterUncreatableType<QAbstractItemModel>(uri, 1, 1, "QAbstractItemModel", "Not instantiable");
+
+    // register 1.1 only API
+    qmlRegisterType<UCStyledItemBase, 1>(uri, 1, 1, "StyledItemBase");
+    qmlRegisterType<QSortFilterProxyModelQML>(uri, 1, 1, "SortFilterModel");
+    qmlRegisterUncreatableType<FilterBehavior>(uri, 1, 1, "FilterBehavior", "Not instantiable");
+    qmlRegisterUncreatableType<SortBehavior>(uri, 1, 1, "SortBehavior", "Not instantiable");
 }
 
 void UbuntuComponentsPlugin::initializeEngine(QQmlEngine *engine, const char *uri)
 {
+    // initialize baseURL
+    m_baseUrl = QUrl(baseUrl().toString() + '/');
+
     QQmlExtensionPlugin::initializeEngine(engine, uri);
     QQmlContext* context = engine->rootContext();
 
-    QuickUtils::instance().setImportPathList(engine->importPathList());
-
     // register root object watcher that sets a global property with the root object
     // that can be accessed from any object
     context->setContextProperty("QuickUtils", &QuickUtils::instance());
@@ -206,15 +209,9 @@ void UbuntuComponentsPlugin::initializeEngine(QQmlEngine *engine, const char *ur
     QObject::connect(&UCUnits::instance(), SIGNAL(gridUnitChanged()),
                      fontUtilsListener, SLOT(updateContextProperty()));
 
-    context->setContextProperty("bottomBarVisibilityCommunicator", &BottomBarVisibilityCommunicator::instance());
-
-    // register UbuntuColors
-    registerQmlSingletonType(engine, uri, "UbuntuColors", "Colors/UbuntuColors.qml");
-
     engine->addImageProvider(QLatin1String("scaling"), new UCScalingImageProvider);
 
-    // register icon providers
-    engine->addImageProvider(QLatin1String("gicon"), new GIconProvider);
+    // register icon provider
     engine->addImageProvider(QLatin1String("theme"), new UnityThemeIconProvider);
 
     try {
