@@ -32,12 +32,9 @@
 
 QuickUtils::QuickUtils(QObject *parent) :
     QObject(parent),
-    m_rootView(0),
-    m_engine(new QQmlEngine)
+    m_rootView(0)
 {
     QGuiApplication::instance()->installEventFilter(this);
-    // connect to focusObjectChanged() to get the latest active focus object
-    QObject::connect(QGuiApplication::instance(), SIGNAL(focusObjectChanged(QObject*)), this, SLOT(activeFocus(QObject*)));
 }
 
 /*!
@@ -48,8 +45,10 @@ QuickUtils::QuickUtils(QObject *parent) :
  */
 bool QuickUtils::eventFilter(QObject *obj, QEvent *event)
 {
-    if (!m_rootView && (event->type() == QEvent::ApplicationActivate))
+    if (!m_rootView && (event->type() == QEvent::ApplicationActivate)) {
         lookupQuickView();
+        Q_EMIT activated();
+    }
     if (event->type() == QEvent::ApplicationDeactivate) {
         Q_EMIT deactivated();
     }
@@ -57,24 +56,6 @@ bool QuickUtils::eventFilter(QObject *obj, QEvent *event)
     return QObject::eventFilter(obj, event);
 }
 
-/*!
- * \internal
- * Catch active focus object change to detecte whether we need to remove OSK or not.
- */
-void QuickUtils::activeFocus(QObject *active)
-{
-    // FIXME: workaround for bug https://bugreports.qt-project.org/browse/QTBUG-30729
-    // input panel does not get removed when no input is active
-    // remove input panel if there's no more active object or the new active object
-    // is not a text input
-    // workaround for bug https://bugs.launchpad.net/ubuntu-ui-toolkit/+bug/1163371
-    if (QGuiApplication::inputMethod()->isVisible() && (!active || (active &&
-                    !qobject_cast<QQuickTextInput*>(active) &&
-                    !qobject_cast<QQuickTextEdit*>(active)))) {
-        QGuiApplication::inputMethod()->hide();
-    }
-}
-
 /*!
  * \internal
  * \deprecated
@@ -114,7 +95,11 @@ QQuickItem *QuickUtils::rootItem(QObject *object)
         // we reach QQuickView's contentItem, whose size is invalid. Therefore
         // we need to return the QQuickView's rootObject() instead of the topmost
         // item found
-        return m_rootView->rootObject();
+        parentItem = m_rootView->rootObject();
+    }
+    // in case the item found is derived from internal QQuickRootItem, return its first child
+    if (parentItem && parentItem->inherits("QQuickRootItem")) {
+        parentItem = parentItem->childItems()[0];
     }
     return parentItem;
 }
@@ -125,82 +110,16 @@ QString QuickUtils::inputMethodProvider() const
     return QString(getenv("QT_IM_MODULE"));
 }
 
-
-/*!
- * \internal
- * Creates an instance out of a delegate using the roles specified in the
- * modelData. Accepts QAbstractListModel, QAbstractProxyModel, QStringList
- * and QVariantList models.
- */
-
-
-qreal QuickUtils::modelDelegateHeight(QQmlComponent *delegate, const QVariant &modelData)
+bool QuickUtils::touchScreenAvailable() const
 {
-    qreal result = 0.0;
-    if (!delegate)
-        return result;
-
-    QQmlContext *creationContext = delegate->creationContext();
-    QQmlContext *context = 0;
-    QAbstractListModel *model = qvariant_cast<QAbstractListModel*>(modelData);
-    QAbstractProxyModel *proxy = qvariant_cast<QAbstractProxyModel*>(modelData);
-
-    if (proxy)
-        model = qobject_cast<QAbstractListModel*>(proxy->sourceModel());
-
-    if (model) {
-        // QAbstractListModel derived models
-
-        if (model->rowCount() > 0) {
-            context = new QQmlContext(creationContext);
-            const QHash<int,QByteArray> roles = model->roleNames();
-            if (roles.count()) {
-
-                // put roles inside the context
-                QHashIterator<int,QByteArray> i(roles);
-                while (i.hasNext()) {
-                    i.next();
-                    context->setContextProperty(i.value(), "");
-                }
-            }
+    // publish internal context property to detect whether we have touch device or not
+    QList<const QTouchDevice*> touchDevices = QTouchDevice::devices();
+    Q_FOREACH(const QTouchDevice *device, touchDevices) {
+        if (device->type() == QTouchDevice::TouchScreen) {
+            return true;
         }
-    } else if (modelData.type() == QVariant::List){
-        QVariantList vModel = qvariant_cast<QVariantList>(modelData);
-        if (vModel.count() > 0) {
-            context = new QQmlContext(creationContext);
-            if (vModel[0].type() == QVariant::String) {
-                // the only role name we have is modelData
-                context->setContextProperty("modelData", "");
-
-            } else if (vModel[0].type() == QVariant::Map) {
-                // we need only the keys, attached to an object named "modelData"
-                context = new QQmlContext(creationContext);
-                QQmlPropertyMap *modelData = new QQmlPropertyMap(context);
-                QVariantMap map = qvariant_cast<QVariantMap>(vModel[0]);
-                QStringList roles = map.uniqueKeys();
-
-                Q_FOREACH(const QString &role, roles)
-                    modelData->insert(role, "");
-
-                context->setContextProperty("modelData", modelData);
-            }
-        }
-    } else if (modelData.type() == QVariant::Int) {
-        context = new QQmlContext(creationContext);
-        // the only role name we have is modelData
-        context->setContextProperty("modelData", 0);
     }
-    if (context) {
-        // add index and section too
-        context->setContextProperty("index", 0);
-        context->setContextProperty("section", "");
-        // create item from component
-        QObject * obj = delegate->create(context);
-        QQuickItem *item = qobject_cast<QQuickItem*>(obj);
-        result = item->height();
-        item->deleteLater();
-    }
-    return result;
+    return false;
 }
 
 /*!
@@ -209,6 +128,9 @@ qreal QuickUtils::modelDelegateHeight(QQmlComponent *delegate, const QVariant &m
  */
 QString QuickUtils::className(QObject *item)
 {
+    if (!item) {
+        return QString("(null)");
+    }
     QString result = item->metaObject()->className();
     return result.left(result.indexOf("_QML"));
 }
@@ -237,19 +159,14 @@ void QuickUtils::lookupQuickView()
     }
 }
 
-QObject* QuickUtils::createQmlObject(const QUrl &url)
+QObject* QuickUtils::createQmlObject(const QUrl &url, QQmlEngine *engine)
 {
     /* FIXME: if the directory pointed to by url contains a qmldir file that
        declares a JavaScript module then QQmlComponent::create() fails with
        the error "QQmlComponent: Component is not ready".
     */
-    QQmlComponent *component = new QQmlComponent(m_engine, url, QQmlComponent::PreferSynchronous);
+    QQmlComponent *component = new QQmlComponent(engine, url, QQmlComponent::PreferSynchronous);
     QObject* result = component->create();
     delete component;
     return result;
 }
-
-void QuickUtils::setImportPathList(const QStringList &paths)
-{
-    m_engine->setImportPathList(paths);
-}
