@@ -30,6 +30,7 @@ class QuickUtils : public QObject
     Q_OBJECT
     Q_PROPERTY(QQuickItem *rootObject READ rootObject NOTIFY rootObjectChanged)
     Q_PROPERTY(QString inputMethodProvider READ inputMethodProvider)
+    Q_PROPERTY(bool touchScreenAvailable READ touchScreenAvailable NOTIFY touchScreenAvailableChanged)
 public:
     static QuickUtils& instance()
     {
@@ -40,6 +41,7 @@ public:
     QQuickItem *rootObject();
     Q_INVOKABLE QQuickItem *rootItem(QObject *object);
     QString inputMethodProvider() const;
+    bool touchScreenAvailable() const;
 
     Q_INVOKABLE static QString className(QObject *item);
     QObject* createQmlObject(const QUrl &url, QQmlEngine *engine);
@@ -48,6 +50,7 @@ Q_SIGNALS:
     void rootObjectChanged();
     void activated();
     void deactivated();
+    void touchScreenAvailableChanged();
 
 protected:
     bool eventFilter(QObject *, QEvent *);
